sequencetools.yield_all_rotations_of_sequence
=============================================

.. autofunction:: abjad.tools.sequencetools.yield_all_rotations_of_sequence.yield_all_rotations_of_sequence
